@@ -22,16 +22,16 @@ from packaging import version
 try:
     import pgmpy
 except:
-    raise ImportError('[bnlearn] >Error: pgmpy v0.1.13 or higher must be installed manually. Try to: <conda install -c ankurankan pgmpy> or <pip install -U pgmpy==0.1.13>')
+    raise ImportError('[bnlearn] >Error: pgmpy version "0.1.13" or higher must be installed manually. Try to: <conda install -c ankurankan pgmpy> or <pip install -U pgmpy>=0.1.13>')
 
 # Check version pgmpy
-if version.parse(pgmpy.__version__)!=version.parse("0.1.13"):
-    raise Exception('[bnlearn] >Error: This release requires pgmpy to be v0.1.13. Try to: <conda install -c ankurankan pgmpy> or <pip install -U pgmpy==0.1.13>')
+if version.parse(pgmpy.__version__) < version.parse("0.1.13"):
+    raise Exception('[bnlearn] >Error: This release requires pgmpy to be version >= 0.1.13. Try to: <conda install -c ankurankan pgmpy> or <pip install -U pgmpy>=0.1.13>')
 
 # Version check
 import matplotlib
-if not version.parse(matplotlib.__version__) > version.parse("3.1.1"):
-    print('[bnlearn] >Error: Matplotlib version should be > v3.1.1.\nTry to: pip install -U matplotlib')
+if not version.parse(matplotlib.__version__) > version.parse("3.3.4"):
+    print('[bnlearn] >Error: Matplotlib version should be > v3.3.4.\nTry to: pip install -U matplotlib')
 
 import networkx as nx
 if not version.parse(nx.__version__) >= version.parse("2.5"):
@@ -40,7 +40,7 @@ if not version.parse(nx.__version__) >= version.parse("2.5"):
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '0.3.12'
+__version__ = '0.3.13'
 
 # module level doc-string
 __doc__ = """
